pub(crate) enum EntityStorageAddResult {
Staged,
Closed(SharedEntity),
}Expand description
Result of trying to stage an entity before full-chunk promotion.
Variants
Staged
The entity was staged in proto-chunk storage.
Closed(SharedEntity)
Promotion already closed storage, so the caller retains the entity.